@@ -9,6 +9,16 @@ from .automl_algorithm import AutoMLAlgorithm, AutoMLAlgorithmException
 from evalml.model_family import ModelFamily
 from evalml.pipelines.utils import _make_stacked_ensemble_pipeline
 
+_ESTIMATOR_FAMILY_ORDER = [
+    ModelFamily.LINEAR_MODEL,
+    ModelFamily.DECISION_TREE,
+    ModelFamily.EXTRA_TREES,
+    ModelFamily.RANDOM_FOREST,
+    ModelFamily.XGBOOST,
+    ModelFamily.LIGHTGBM,
+    ModelFamily.CATBOOST
+]
+
 
 class IterativeAlgorithm(AutoMLAlgorithm):
     """An automl algorithm which first fits a base round of pipelines with default parameters, then does a round of parameter tuning on each pipeline in order of performance."""
@@ -22,11 +32,13 @@ class IterativeAlgorithm(AutoMLAlgorithm):
                  n_jobs=-1,  # TODO remove
                  number_features=None,  # TODO remove
                  ensembling=False,
-                 pipeline_params=None):
+                 pipeline_params=None,
+                 _frozen_pipeline_parameters=None,
+                 _estimator_family_order=None):
         """An automl algorithm which first fits a base round of pipelines with default parameters, then does a round of parameter tuning on each pipeline in order of performance.
 
         Arguments:
-            allowed_pipelines (list(class)): A list of PipelineBase subclasses indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
+            allowed_pipelines (list(class)): A list of PipelineBase instances indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
             max_iterations (int): The maximum number of iterations to be evaluated.
             tuner_class (class): A subclass of Tuner, to be used to find parameters for each pipeline. The default of None indicates the SKOptTuner will be used.
             random_seed (int): Seed for the random number generator. Defaults to 0.
@@ -35,7 +47,23 @@ class IterativeAlgorithm(AutoMLAlgorithm):
             number_features (int): The number of columns in the input features.
             ensembling (boolean): If True, runs ensembling in a separate batch after every allowed pipeline class has been iterated over. Defaults to False.
             pipeline_params (dict or None): Pipeline-level parameters that should be passed to the proposed pipelines.
+            _frozen_pipeline_parameters (dict or None): Pipeline-level parameters are frozen and used in the proposed pipelines.
+            _estimator_family_order (list(ModelFamily) or None): specify the sort order for the first batch. Defaults to _ESTIMATOR_FAMILY_ORDER.
         """
+        self._estimator_family_order = _estimator_family_order or _ESTIMATOR_FAMILY_ORDER
+        indices = []
+        pipelines_to_sort = []
+        pipelines_end = []
+        for pipeline in allowed_pipelines or []:
+            if pipeline.model_family in self._estimator_family_order:
+                indices.append(self._estimator_family_order.index(pipeline.model_family))
+                pipelines_to_sort.append(pipeline)
+            else:
+                pipelines_end.append(pipeline)
+        pipelines_start = [pipeline for _, pipeline in (sorted(zip(indices, pipelines_to_sort),
+                                                               key=lambda pair: pair[0]) or [])]
+        allowed_pipelines = pipelines_start + pipelines_end
+
         super().__init__(allowed_pipelines=allowed_pipelines,
                          max_iterations=max_iterations,
                          tuner_class=tuner_class,
@@ -47,6 +75,7 @@ class IterativeAlgorithm(AutoMLAlgorithm):
         self._best_pipeline_info = {}
         self.ensembling = ensembling and len(self.allowed_pipelines) > 1
         self._pipeline_params = pipeline_params or {}
+        self._frozen_pipeline_parameters = _frozen_pipeline_parameters or {}
 
     def next_batch(self):
         """Get the next batch of pipelines to evaluate
@@ -61,8 +90,8 @@ class IterativeAlgorithm(AutoMLAlgorithm):
 
         next_batch = []
         if self._batch_number == 0:
-            next_batch = [pipeline_class(parameters=self._transform_parameters(pipeline_class, {}), random_seed=self.random_seed)
-                          for pipeline_class in self.allowed_pipelines]
+            next_batch = [pipeline.new(parameters=self._combine_parameters(pipeline, {}), random_seed=self.random_seed)
+                          for pipeline in self.allowed_pipelines]
 
         # One after training all pipelines one round
         elif (self.ensembling and
@@ -70,27 +99,32 @@ class IterativeAlgorithm(AutoMLAlgorithm):
               (self._batch_number) % (len(self._first_batch_results) + 1) == 0):
             input_pipelines = []
             for pipeline_dict in self._best_pipeline_info.values():
-                pipeline_class = pipeline_dict['pipeline_class']
+                pipeline = pipeline_dict['pipeline']
                 pipeline_params = pipeline_dict['parameters']
-                input_pipelines.append(pipeline_class(parameters=self._transform_parameters(pipeline_class, pipeline_params),
-                                                      random_seed=self.random_seed))
+                parameters = self._combine_parameters(pipeline, pipeline_params)
+                input_pipelines.append(pipeline.new(parameters=parameters,
+                                                    random_seed=self.random_seed))
             ensemble = _make_stacked_ensemble_pipeline(input_pipelines, input_pipelines[0].problem_type,
                                                        random_seed=self.random_seed,
                                                        n_jobs=self.n_jobs)
 
             next_batch.append(ensemble)
         else:
-            num_pipeline_classes = (len(self._first_batch_results) + 1) if self.ensembling else len(self._first_batch_results)
-            idx = (self._batch_number - 1) % num_pipeline_classes
-            pipeline_class = self._first_batch_results[idx][1]
+            num_pipelines = (len(self._first_batch_results) + 1) if self.ensembling else len(self._first_batch_results)
+            idx = (self._batch_number - 1) % num_pipelines
+            pipeline = self._first_batch_results[idx][1]
             for i in range(self.pipelines_per_batch):
-                proposed_parameters = self._tuners[pipeline_class.name].propose()
-                pl_parameters = self._transform_parameters(pipeline_class, proposed_parameters)
-                next_batch.append(pipeline_class(parameters=pl_parameters, random_seed=self.random_seed))
+                proposed_parameters = self._tuners[pipeline.name].propose()
+                parameters = self._combine_parameters(pipeline, proposed_parameters)
+                next_batch.append(pipeline.new(parameters=parameters, random_seed=self.random_seed))
         self._pipeline_number += len(next_batch)
         self._batch_number += 1
         return next_batch
 
+    def _combine_parameters(self, pipeline, proposed_parameters):
+        """Helper function for logic to transform proposed parameters and frozen parameters."""
+        return {**self._transform_parameters(pipeline, proposed_parameters), **self._frozen_pipeline_parameters}
+
     def add_result(self, score_to_minimize, pipeline, trained_pipeline_results):
         """Register results from evaluating a pipeline
 
@@ -111,22 +145,21 @@ class IterativeAlgorithm(AutoMLAlgorithm):
             else:
                 super().add_result(score_to_minimize, pipeline, trained_pipeline_results)
         if self.batch_number == 1:
-            self._first_batch_results.append((score_to_minimize, pipeline.__class__))
-
-        current_best_score = self._best_pipeline_info.get(pipeline.model_family, {}).get("mean_cv_score", np.inf)
+            self._first_batch_results.append((score_to_minimize, pipeline))
+        current_best_score = self._best_pipeline_info.get(pipeline.model_family, {}).get('mean_cv_score', np.inf)
         if score_to_minimize is not None and score_to_minimize < current_best_score and pipeline.model_family != ModelFamily.ENSEMBLE:
-            self._best_pipeline_info.update({pipeline.model_family: {"mean_cv_score": score_to_minimize,
-                                                                     'pipeline_class': pipeline.__class__,
+            self._best_pipeline_info.update({pipeline.model_family: {'mean_cv_score': score_to_minimize,
+                                                                     'pipeline': pipeline,
                                                                      'parameters': pipeline.parameters,
                                                                      'id': trained_pipeline_results['id']}
                                              })
 
-    def _transform_parameters(self, pipeline_class, proposed_parameters):
+    def _transform_parameters(self, pipeline, proposed_parameters):
         """Given a pipeline parameters dict, make sure n_jobs and number_features are set."""
         parameters = {}
         if 'pipeline' in self._pipeline_params:
             parameters['pipeline'] = self._pipeline_params['pipeline']
-        for name, component_class in pipeline_class.linearized_component_graph:
+        for name, component_class in pipeline.linearized_component_graph:
             component_parameters = proposed_parameters.get(name, {})
             init_params = inspect.signature(component_class.__init__).parameters
 
@@ -145,6 +178,8 @@ class IterativeAlgorithm(AutoMLAlgorithm):
                         component_parameters[param_name] = value.rvs(random_state=self.random_seed)
                     else:
                         component_parameters[param_name] = value
+            if name in self._pipeline_params and name == 'Drop Columns Transformer' and self._batch_number > 0:
+                component_parameters['columns'] = self._pipeline_params[name]['columns']
             if 'pipeline' in self._pipeline_params:
                 for param_name, value in self._pipeline_params['pipeline'].items():
                     if param_name in init_params:
