@@ -6,3 +6,6 @@ class DataCheckActionCode(Enum):
 
     DROP_COL = "drop_col"
     """Action code for dropping a column."""
+
+    IMPUTE_COL = "impute_col"
+    """Action code for imputing a column."""
