@@ -31,7 +31,7 @@ class DataCheckMessageCode(Enum):
     TARGET_BINARY_INVALID_VALUES = "target_binary_invalid_values"
     """Message code for target data for a binary classification problem with numerical values not equal to {0, 1}."""
 
-    TARGET_BINARY_NOT_TWO_EXAMPLES_PER_CLASS = "target_multiclass_not_two_examples_per_class"
+    TARGET_MULTICLASS_NOT_TWO_EXAMPLES_PER_CLASS = "target_multiclass_not_two_examples_per_class"
     """Message code for target data for a multi classification problem that does not have two examples per class."""
 
     TARGET_MULTICLASS_NOT_ENOUGH_CLASSES = "target_multiclass_not_enough_classes"
@@ -87,3 +87,6 @@ class DataCheckMessageCode(Enum):
 
     DATETIME_HAS_NAN = "datetime_has_nan"
     """Message code for when input datetime columns contain NaN values."""
+
+    NATURAL_LANGUAGE_HAS_NAN = "natural_language_has_nan"
+    """Message code for when input natural language columns contain NaN values."""
