@@ -18,7 +18,7 @@ class StackedEnsembleRegressor(StackedEnsembleBase):
     _default_cv = KFold
 
     def __init__(self, input_pipelines=None, final_estimator=None,
-                 cv=None, n_jobs=-1, random_state=None, random_seed=0, **kwargs):
+                 cv=None, n_jobs=-1, random_seed=0, **kwargs):
         """Stacked ensemble regressor.
 
         Arguments:
@@ -37,8 +37,7 @@ class StackedEnsembleRegressor(StackedEnsembleBase):
                 None and 1 are equivalent. If set to -1, all CPUs are used. For n_jobs below -1, (n_cpus + 1 + n_jobs) are used.
                 Defaults to None.
                 - Note: there could be some multi-process errors thrown for values of `n_jobs != 1`. If this is the case, please use `n_jobs = 1`.
-            random_state (None, int): Deprecated - use random_seed instead.
             random_seed (int): Seed for the random number generator. Defaults to 0.
         """
         super().__init__(input_pipelines=input_pipelines, final_estimator=final_estimator, cv=cv,
-                         n_jobs=n_jobs, random_state=random_state, random_seed=random_seed, **kwargs)
+                         n_jobs=n_jobs, random_seed=random_seed, **kwargs)
