@@ -18,28 +18,35 @@ from evalml.utils import (
 
 
 class TimeSeriesClassificationPipeline(ClassificationPipeline, metaclass=TimeSeriesPipelineBaseMeta):
-    """Pipeline base class for time series classifcation problems."""
+    """Pipeline base class for time series classification problems."""
 
-    def __init__(self, parameters, random_seed=0):
+    def __init__(self, component_graph, parameters=None, custom_name=None, custom_hyperparameters=None, random_seed=0):
         """Machine learning pipeline for time series classification problems made out of transformers and a classifier.
 
-        Required Class Variables:
-            component_graph (list): List of components in order. Accepts strings or ComponentBase subclasses in the list
-
         Arguments:
+            component_graph (list or dict): List of components in order. Accepts strings or ComponentBase subclasses in the list.
+                Note that when duplicate components are specified in a list, the duplicate component names will be modified with the
+                component's index in the list. For example, the component graph
+                [Imputer, One Hot Encoder, Imputer, Logistic Regression Classifier] will have names
+                ["Imputer", "One Hot Encoder", "Imputer_2", "Logistic Regression Classifier"]
             parameters (dict): Dictionary with component names as keys and dictionary of that component's parameters as values.
                  An empty dictionary {} implies using all default values for component parameters. Pipeline-level
-                 parameters such as gap and max_delay must be specified with the "pipeline" key. For example:
-                 Pipeline(parameters={"pipeline": {"max_delay": 4, "gap": 2}}).
+                 parameters such as date_index, gap, and max_delay must be specified with the "pipeline" key. For example:
+                 Pipeline(parameters={"pipeline": {"date_index": "Date", "max_delay": 4, "gap": 2}}).
             random_seed (int): Seed for the random number generator. Defaults to 0.
         """
         if "pipeline" not in parameters:
-            raise ValueError("gap and max_delay parameters cannot be omitted from the parameters dict. "
+            raise ValueError("date_index, gap, and max_delay parameters cannot be omitted from the parameters dict. "
                              "Please specify them as a dictionary with the key 'pipeline'.")
         pipeline_params = parameters["pipeline"]
+        self.date_index = pipeline_params['date_index']
         self.gap = pipeline_params['gap']
         self.max_delay = pipeline_params['max_delay']
-        super().__init__(parameters, random_seed)
+        super().__init__(component_graph,
+                         custom_name=custom_name,
+                         parameters=parameters,
+                         custom_hyperparameters=custom_hyperparameters,
+                         random_seed=random_seed)
 
     @staticmethod
     def _convert_to_woodwork(X, y):
