@@ -6,7 +6,7 @@ from sklearn.model_selection._split import BaseCrossValidator
 class TrainingValidationSplit(BaseCrossValidator):
     """Split the training data into training and validation sets"""
 
-    def __init__(self, test_size=None, train_size=None, shuffle=False, stratify=None, random_state=0):
+    def __init__(self, test_size=None, train_size=None, shuffle=False, stratify=None, random_seed=0):
         """Create a TrainingValidation instance
 
         Arguments:
@@ -25,7 +25,7 @@ class TrainingValidationSplit(BaseCrossValidator):
         self.train_size = train_size
         self.shuffle = shuffle
         self.stratify = stratify
-        self.random_state = random_state
+        self.random_seed = random_seed
 
     @staticmethod
     def get_n_splits():
@@ -42,5 +42,5 @@ class TrainingValidationSplit(BaseCrossValidator):
             Returns:
                 list: Indices to split data into training and test set
         """
-        train, test = train_test_split(np.arange(X.shape[0]), test_size=self.test_size, train_size=self.train_size, shuffle=self.shuffle, stratify=self.stratify, random_state=self.random_state)
+        train, test = train_test_split(np.arange(X.shape[0]), test_size=self.test_size, train_size=self.train_size, shuffle=self.shuffle, stratify=self.stratify, random_state=self.random_seed)
         return iter([(train, test)])
