@@ -8,9 +8,9 @@ from evalml.exceptions import ObjectiveNotFoundError
 from evalml.model_family import ModelFamily
 from evalml.objectives import MeanSquaredLogError, RootMeanSquaredLogError
 from evalml.pipelines import (
-    MeanBaselineRegressionPipeline,
     PipelineBase,
-    TimeSeriesBaselineRegressionPipeline
+    RegressionPipeline,
+    TimeSeriesRegressionPipeline
 )
 from evalml.pipelines.components.utils import get_estimators
 from evalml.pipelines.utils import make_pipeline
@@ -153,9 +153,10 @@ def test_automl_allowed_pipelines_no_allowed_pipelines(X_y_regression):
 @patch('evalml.pipelines.RegressionPipeline.fit')
 def test_automl_allowed_pipelines_specified_allowed_pipelines(mock_fit, mock_score, dummy_regression_pipeline_class, X_y_regression):
     X, y = X_y_regression
-    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class], allowed_model_families=None)
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression',
+                          allowed_pipelines=[dummy_regression_pipeline_class({})], allowed_model_families=None)
     mock_score.return_value = {automl.objective.name: 1.0}
-    expected_pipelines = [dummy_regression_pipeline_class]
+    expected_pipelines = [dummy_regression_pipeline_class({})]
     mock_score.return_value = {automl.objective.name: 1.0}
     assert automl.allowed_pipelines == expected_pipelines
     assert automl.allowed_model_families == [ModelFamily.NONE]
@@ -209,9 +210,9 @@ def test_automl_allowed_pipelines_init_allowed_both_not_specified(mock_fit, mock
 @patch('evalml.pipelines.RegressionPipeline.fit')
 def test_automl_allowed_pipelines_init_allowed_both_specified(mock_fit, mock_score, dummy_regression_pipeline_class, X_y_regression, assert_allowed_pipelines_equal_helper):
     X, y = X_y_regression
-    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class], allowed_model_families=[ModelFamily.RANDOM_FOREST])
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', allowed_pipelines=[dummy_regression_pipeline_class({})], allowed_model_families=[ModelFamily.RANDOM_FOREST])
     mock_score.return_value = {automl.objective.name: 1.0}
-    expected_pipelines = [dummy_regression_pipeline_class]
+    expected_pipelines = [dummy_regression_pipeline_class({})]
     assert_allowed_pipelines_equal_helper(automl.allowed_pipelines, expected_pipelines)
     assert set(automl.allowed_model_families) == set([p.model_family for p in expected_pipelines])
     automl.search()
@@ -225,28 +226,28 @@ def test_automl_allowed_pipelines_search(mock_fit, mock_score, dummy_regression_
     X, y = X_y_regression
     mock_score.return_value = {'R2': 1.0}
 
-    allowed_pipelines = [dummy_regression_pipeline_class]
+    allowed_pipelines = [dummy_regression_pipeline_class({})]
     start_iteration_callback = MagicMock()
     automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_iterations=2, start_iteration_callback=start_iteration_callback,
                           allowed_pipelines=allowed_pipelines)
     automl.search()
 
     assert start_iteration_callback.call_count == 2
-    assert start_iteration_callback.call_args_list[0][0][0] == MeanBaselineRegressionPipeline
+    assert start_iteration_callback.call_args_list[0][0][0] == RegressionPipeline
     assert start_iteration_callback.call_args_list[1][0][0] == dummy_regression_pipeline_class
 
 
 def test_automl_regression_nonlinear_pipeline_search(nonlinear_regression_pipeline_class, X_y_regression):
     X, y = X_y_regression
 
-    allowed_pipelines = [nonlinear_regression_pipeline_class]
+    allowed_pipelines = [nonlinear_regression_pipeline_class({})]
     start_iteration_callback = MagicMock()
     automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression', max_iterations=2, start_iteration_callback=start_iteration_callback,
                           allowed_pipelines=allowed_pipelines, n_jobs=1)
     automl.search()
 
     assert start_iteration_callback.call_count == 2
-    assert start_iteration_callback.call_args_list[0][0][0] == MeanBaselineRegressionPipeline
+    assert start_iteration_callback.call_args_list[0][0][0] == RegressionPipeline
     assert start_iteration_callback.call_args_list[1][0][0] == nonlinear_regression_pipeline_class
 
 
@@ -254,17 +255,27 @@ def test_automl_regression_nonlinear_pipeline_search(nonlinear_regression_pipeli
 @patch('evalml.pipelines.TimeSeriesRegressionPipeline.fit')
 def test_automl_supports_time_series_regression(mock_fit, mock_score, X_y_regression):
     X, y = X_y_regression
+    X = pd.DataFrame(X, columns=[f"Column_{str(i)}" for i in range(20)])
+    X["Date"] = pd.date_range(start='1/1/2018', periods=X.shape[0])
 
-    configuration = {"gap": 0, "max_delay": 0, 'delay_target': False, 'delay_features': True}
+    configuration = {"date_index": "Date", "gap": 0, "max_delay": 0, 'delay_target': False, 'delay_features': True}
 
     automl = AutoMLSearch(X_train=X, y_train=y, problem_type="time series regression", problem_configuration=configuration,
                           max_batches=2)
     automl.search()
     assert isinstance(automl.data_splitter, TimeSeriesSplit)
     for result in automl.results['pipeline_results'].values():
-        if result["id"] == 0:
-            assert result['pipeline_class'] == TimeSeriesBaselineRegressionPipeline
-            continue
+        assert result['pipeline_class'] == TimeSeriesRegressionPipeline
 
-        assert result['parameters']['Delayed Feature Transformer'] == configuration
-        assert result['parameters']['pipeline'] == configuration
+        if result["id"] == 0:
+            continue
+        for param_key, param_val in configuration.items():
+            assert result['parameters']['Delayed Feature Transformer'][param_key] == configuration[param_key]
+            assert result['parameters']['pipeline'][param_key] == configuration[param_key]
+
+
+def test_automl_regression_no_sampler(X_y_regression):
+    X, y = X_y_regression
+    automl = AutoMLSearch(X_train=X, y_train=y, problem_type='regression')
+    for pipeline in automl.allowed_pipelines:
+        assert not any("sampler" in c.name for c in pipeline.component_graph)
