@@ -17,6 +17,7 @@ from evalml.exceptions import (
     MethodPropertyNotFoundError
 )
 from evalml.model_family import ModelFamily
+from evalml.pipelines import BinaryClassificationPipeline, RegressionPipeline
 from evalml.pipelines.components import (
     LSA,
     PCA,
@@ -50,6 +51,9 @@ from evalml.pipelines.components import (
     RFRegressorSelectFromModel,
     SelectColumns,
     SimpleImputer,
+    SMOTENCSampler,
+    SMOTENSampler,
+    SMOTESampler,
     StandardScaler,
     SVMClassifier,
     SVMRegressor,
@@ -71,7 +75,6 @@ from evalml.pipelines.components.utils import (
     all_components,
     generate_component_code
 )
-from evalml.pipelines.utils import make_pipeline_from_components
 from evalml.problem_types import ProblemTypes
 
 
@@ -177,13 +180,23 @@ def test_describe_component():
     assert drop_null_transformer.describe(return_dict=True) == {'name': 'Drop Null Columns Transformer', 'parameters': {'pct_null_threshold': 1.0}}
     assert datetime.describe(return_dict=True) == {'name': 'DateTime Featurization Component',
                                                    'parameters': {'features_to_extract': ['year', 'month', 'day_of_week', 'hour'],
-                                                                  'encode_as_categories': False}}
+                                                                  'encode_as_categories': False,
+                                                                  'date_index': None}}
     assert text_featurizer.describe(return_dict=True) == {'name': 'Text Featurization Component', 'parameters': {}}
     assert lsa.describe(return_dict=True) == {'name': 'LSA Transformer', 'parameters': {}}
     assert pca.describe(return_dict=True) == {'name': 'PCA Transformer', 'parameters': {'n_components': None, 'variance': 0.95}}
     assert lda.describe(return_dict=True) == {'name': 'Linear Discriminant Analysis Transformer', 'parameters': {'n_components': None}}
     assert ft.describe(return_dict=True) == {'name': 'DFS Transformer', 'parameters': {"index": "index"}}
     assert us.describe(return_dict=True) == {'name': 'Undersampler', 'parameters': {"sampling_ratio": 0.25, "min_samples": 100, "min_percentage": 0.1}}
+    try:
+        smote = SMOTESampler()
+        assert smote.describe(return_dict=True) == {'name': 'SMOTE Oversampler', 'parameters': {'sampling_ratio': 0.25, 'k_neighbors': 5, 'n_jobs': -1}}
+        smote = SMOTENCSampler()
+        assert smote.describe(return_dict=True) == {'name': 'SMOTENC Oversampler', 'parameters': {'sampling_ratio': 0.25, 'k_neighbors': 5, 'n_jobs': -1}}
+        smote = SMOTENSampler()
+        assert smote.describe(return_dict=True) == {'name': 'SMOTEN Oversampler', 'parameters': {'sampling_ratio': 0.25, 'k_neighbors': 5, 'n_jobs': -1}}
+    except ImportError:
+        pass
     # testing estimators
     base_classifier = BaselineClassifier()
     base_regressor = BaselineRegressor()
@@ -534,6 +547,12 @@ def test_transformer_transform_output_type(X_y_binary):
                           y.name if isinstance(y, pd.Series) else None))
 
             component = component_class()
+            # SMOTE will throw an error if we pass a ratio lower than the current class balance
+            if "SMOTE" in component_class.name:
+                component = component_class(sampling_ratio=1)
+            if component_class.name == "SMOTENC Oversampler":
+                # we cover this case in test_oversamplers
+                continue
 
             component.fit(X, y=y)
             transform_output = component.transform(X, y=y)
@@ -728,6 +747,13 @@ def test_all_transformers_check_fit(X_y_binary):
             continue
 
         component = component_class()
+        # SMOTE will throw errors if we call it but cannot oversample
+        if "SMOTE" in component_class.name:
+            component = component_class(sampling_ratio=1)
+        if component_class.name == "SMOTENC Oversampler":
+            # handled in test_oversamplers
+            continue
+
         with pytest.raises(ComponentNotYetFittedError, match=f'You must fit {component_class.__name__}'):
             component.transform(X, y)
 
@@ -735,6 +761,8 @@ def test_all_transformers_check_fit(X_y_binary):
         component.transform(X, y)
 
         component = component_class()
+        if "SMOTE" in component_class.name:
+            component = component_class(sampling_ratio=1)
         component.fit_transform(X, y)
         component.transform(X, y)
 
@@ -775,7 +803,8 @@ def test_all_transformers_check_fit_input_type(data_type, X_y_binary, make_data_
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
     for component_class in _all_transformers():
-        if not component_class.needs_fitting:
+        if not component_class.needs_fitting or "SMOTENC" in component_class.name:
+            # since SMOTENC determines categorical columns through the logical type, it can only accept ww data
             continue
 
         component = component_class()
@@ -801,9 +830,10 @@ def test_serialization(X_y_binary, ts_data, tmpdir, helper_functions):
             component = helper_functions.safe_init_component_with_njobs_1(component_class)
         except EnsembleMissingPipelinesError:
             if (component_class == StackedEnsembleClassifier):
-                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestClassifier()], ProblemTypes.BINARY)], n_jobs=1)
+                component = component_class(input_pipelines=[BinaryClassificationPipeline([RandomForestClassifier],
+                                                                                          parameters={"Random Forest Classifier": {"n_jobs": 1}})])
             elif (component_class == StackedEnsembleRegressor):
-                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestRegressor()], ProblemTypes.REGRESSION)], n_jobs=1)
+                component = component_class(input_pipelines=[RegressionPipeline([RandomForestRegressor], parameters={"Random Forest Regressor": {"n_jobs": 1}})])
         if isinstance(component, Estimator) and ProblemTypes.TIME_SERIES_REGRESSION in component.supported_problem_types:
             X, y = ts_data
         else:
@@ -1014,7 +1044,7 @@ def test_categorical_hyperparameters(X_y_binary, categorical):
 
 def test_generate_code_errors():
     with pytest.raises(ValueError, match="Element must be a component instance"):
-        generate_component_code(make_pipeline_from_components([RandomForestClassifier()], ProblemTypes.BINARY))
+        generate_component_code(BinaryClassificationPipeline([RandomForestClassifier]))
 
     with pytest.raises(ValueError, match="Element must be a component instance"):
         generate_component_code(LinearRegressor)
