@@ -1,7 +1,15 @@
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 from pandas.testing import assert_frame_equal
+from woodwork.logical_types import (
+    Boolean,
+    Categorical,
+    Double,
+    Integer,
+    NaturalLanguage
+)
 
 from evalml.pipelines.components import Imputer
 
@@ -18,7 +26,7 @@ def imputer_test_data():
         "int with nan": [np.nan, 1, 0, 0, 1],
         "float with nan": [0.0, 1.0, np.nan, -1.0, 0.],
         "object with nan": ["b", "b", np.nan, "c", np.nan],
-        "bool col with nan": [True, np.nan, False, np.nan, True],
+        "bool col with nan": pd.Series([True, np.nan, False, np.nan, True], dtype='boolean'),
         "all nan": [np.nan, np.nan, np.nan, np.nan, np.nan],
         "all nan cat": pd.Series([np.nan, np.nan, np.nan, np.nan, np.nan], dtype='category')
     })
@@ -264,7 +272,7 @@ def test_imputer_with_none():
     X = pd.DataFrame({"int with None": [1, 0, 5, None],
                       "float with None": [0.1, 0.0, 0.5, None],
                       "category with None": pd.Series(["b", "a", "a", None], dtype='category'),
-                      "boolean with None": [True, None, False, True],
+                      "boolean with None": pd.Series([True, None, False, True], dtype='boolean'),
                       "object with None": ["b", "a", "a", None],
                       "all None": [None, None, None, None]})
     y = pd.Series([0, 0, 1, 0, 1])
@@ -274,13 +282,13 @@ def test_imputer_with_none():
     expected = pd.DataFrame({"int with None": [1, 0, 5, 2],
                              "float with None": [0.1, 0.0, 0.5, 0.2],
                              "category with None": pd.Series(["b", "a", "a", "a"], dtype='category'),
-                             "boolean with None": [True, True, False, True],
+                             "boolean with None": pd.Series([True, True, False, True], dtype='boolean'),
                              "object with None": pd.Series(["b", "a", "a", "a"], dtype='category')})
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
 
     imputer = Imputer()
     transformed = imputer.fit_transform(X, y)
-    assert_frame_equal(transformed.to_dataframe(), expected, check_dtype=False)
+    assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
@@ -297,7 +305,7 @@ def test_imputer_all_bool_return_original(data_type, make_data_type):
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_imputer_bool_dtype_object(data_type, make_data_type):
-    X = pd.DataFrame([True, np.nan, False, np.nan, True], dtype=object)
+    X = pd.DataFrame([True, np.nan, False, np.nan, True], dtype='boolean')
     y = pd.Series([1, 0, 0, 1, 0])
     X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='boolean')
     X = make_data_type(data_type, X)
@@ -311,7 +319,7 @@ def test_imputer_bool_dtype_object(data_type, make_data_type):
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_imputer_multitype_with_one_bool(data_type, make_data_type):
     X_multi = pd.DataFrame({
-        "bool with nan": pd.Series([True, np.nan, False, np.nan, False], dtype=object),
+        "bool with nan": pd.Series([True, np.nan, False, np.nan, False], dtype='boolean'),
         "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
     })
     y = pd.Series([1, 0, 0, 1, 0])
@@ -327,3 +335,33 @@ def test_imputer_multitype_with_one_bool(data_type, make_data_type):
     imputer.fit(X_multi, y)
     X_multi_t = imputer.transform(X_multi)
     assert_frame_equal(X_multi_expected_arr, X_multi_t.to_dataframe())
+
+
+@pytest.mark.parametrize("X_df", [pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
+                                  pd.DataFrame(pd.Series([1., 2., 4.], dtype="float")),
+                                  pd.DataFrame(pd.Series(['a', 'b', 'a'], dtype="category")),
+                                  pd.DataFrame(pd.Series([True, False, True], dtype="boolean")),
+                                  pd.DataFrame(pd.Series(['this will be a natural language column because length', 'yay', 'hay'], dtype="string"))])
+@pytest.mark.parametrize("has_nan", [True, False])
+@pytest.mark.parametrize("numeric_impute_strategy", ["mean", "median", "most_frequent"])
+def test_imputer_woodwork_custom_overrides_returned_by_components(X_df, has_nan, numeric_impute_strategy):
+    y = pd.Series([1, 2, 1])
+    if has_nan:
+        X_df.iloc[len(X_df) - 1, 0] = np.nan
+    override_types = [Integer, Double, Categorical, NaturalLanguage, Boolean]
+    for logical_type in override_types:
+        try:
+            X = ww.DataTable(X_df, logical_types={0: logical_type})
+        except TypeError:
+            continue
+
+        imputer = Imputer(numeric_impute_strategy=numeric_impute_strategy)
+        imputer.fit(X, y)
+        transformed = imputer.transform(X, y)
+        assert isinstance(transformed, ww.DataTable)
+        if numeric_impute_strategy == "most_frequent":
+            assert transformed.logical_types == {0: logical_type}
+        elif logical_type in [Categorical, NaturalLanguage] or not has_nan:
+            assert transformed.logical_types == {0: logical_type}
+        else:
+            assert transformed.logical_types == {0: Double}
