@@ -1,3 +1,5 @@
+from unittest.mock import MagicMock
+
 import numpy as np
 import pandas as pd
 import pytest
@@ -75,11 +77,11 @@ def test_empty_data_checks(input_type, X_y_binary):
 messages = [DataCheckWarning(message="Column 'all_null' is 95.0% or more null",
                              data_check_name="HighlyNullDataCheck",
                              message_code=DataCheckMessageCode.HIGHLY_NULL,
-                             details={"column": "all_null"}).to_dict(),
+                             details={"column": "all_null", "pct_null_rows": 1.0}).to_dict(),
             DataCheckWarning(message="Column 'also_all_null' is 95.0% or more null",
                              data_check_name="HighlyNullDataCheck",
                              message_code=DataCheckMessageCode.HIGHLY_NULL,
-                             details={"column": "also_all_null"}).to_dict(),
+                             details={"column": "also_all_null", "pct_null_rows": 1.0}).to_dict(),
             DataCheckWarning(message="Column 'id' is 100.0% or more likely to be an ID column",
                              data_check_name="IDColumnsDataCheck",
                              message_code=DataCheckMessageCode.HAS_ID_COLUMN,
@@ -352,3 +354,25 @@ def test_data_checks_do_not_duplicate_actions(X_y_binary):
         "errors": [],
         "actions": [DataCheckAction(DataCheckActionCode.DROP_COL, metadata={"column": 'col_to_drop'}).to_dict()]
     }
+
+
+def test_data_checks_drop_index(X_y_binary):
+    X, y = X_y_binary
+    X = pd.DataFrame(X)
+    X['index_col'] = pd.Series(range(len(X)))
+    X = ww.DataTable(X)
+    X = X.set_index('index_col')
+
+    class MockDataCheck(DataCheck):
+        def validate(self, X, y):
+            return {"warnings": [], "errors": [], "actions": []}
+
+    assert MockDataCheck().validate(X, y)
+
+    MockDataCheck.validate = MagicMock()
+    checks = DataChecks([MockDataCheck, MockDataCheck, MockDataCheck])
+    checks.validate(X, y)
+
+    validate_args = MockDataCheck.validate.call_args_list
+    for arg in validate_args:
+        assert 'index_col' not in arg[0][0].columns
