@@ -1,5 +1,6 @@
+import warnings
 from itertools import product
-from unittest.mock import patch
+from unittest.mock import MagicMock, patch
 
 import numpy as np
 import pandas as pd
@@ -14,19 +15,16 @@ from evalml.model_understanding.prediction_explanations._algorithms import (
 )
 from evalml.pipelines import (
     BinaryClassificationPipeline,
-    MeanBaselineRegressionPipeline,
-    ModeBaselineBinaryPipeline,
-    ModeBaselineMulticlassPipeline,
     MulticlassClassificationPipeline,
     RegressionPipeline,
-    TimeSeriesBaselineRegressionPipeline
+    TimeSeriesRegressionPipeline
 )
 from evalml.pipelines.components import (
-    CatBoostClassifier,
+    BaselineClassifier,
+    BaselineRegressor,
     LinearRegressor,
     RandomForestClassifier,
-    XGBoostClassifier,
-    XGBoostRegressor
+    TimeSeriesBaselineEstimator
 )
 from evalml.pipelines.components.utils import _all_estimators_used_in_search
 from evalml.pipelines.utils import make_pipeline
@@ -35,45 +33,42 @@ from evalml.problem_types.problem_types import ProblemTypes
 
 def make_test_pipeline(estimator, base_class):
     """Make an estimator-only pipeline.
-
     This is helps test the exceptions raised in _compute_shap_values without having to use make_pipeline
     (which needs training data to be passed in).
     """
 
     class Pipeline(base_class):
         component_graph = [estimator]
-        name = estimator.name
+        custom_name = estimator.name
+
+        def __init__(self, parameters, random_seed=0):
+            super().__init__(self.component_graph, parameters=parameters, custom_name=self.custom_name, custom_hyperparameters=None, random_seed=random_seed)
 
     return Pipeline
 
 
 baseline_message = "You passed in a baseline pipeline. These are simple enough that SHAP values are not needed."
-xg_boost_message = "SHAP values cannot currently be computed for xgboost models."
-catboost_message = "SHAP values cannot currently be computed for catboost models for multiclass problems."
 datatype_message = "^Unknown shap_values datatype"
 data_message = "You must pass in a value for parameter 'training_data' when the pipeline does not have a tree-based estimator. Current estimator model family is Linear."
 
 
-@pytest.mark.parametrize("pipeline,exception,match", [(MeanBaselineRegressionPipeline, ValueError, baseline_message),
-                                                      (ModeBaselineBinaryPipeline, ValueError, baseline_message),
-                                                      (ModeBaselineMulticlassPipeline, ValueError, baseline_message),
-                                                      (TimeSeriesBaselineRegressionPipeline, ValueError, baseline_message),
-                                                      (make_test_pipeline(CatBoostClassifier, MulticlassClassificationPipeline), NotImplementedError, catboost_message),
-                                                      (make_test_pipeline(XGBoostClassifier, BinaryClassificationPipeline), NotImplementedError, xg_boost_message),
-                                                      (make_test_pipeline(XGBoostClassifier, MulticlassClassificationPipeline), NotImplementedError, xg_boost_message),
-                                                      (make_test_pipeline(XGBoostRegressor, RegressionPipeline), NotImplementedError, xg_boost_message),
+@pytest.mark.parametrize("pipeline,exception,match", [(make_test_pipeline(BaselineRegressor, RegressionPipeline), ValueError, baseline_message),
+                                                      (make_test_pipeline(BaselineClassifier, BinaryClassificationPipeline), ValueError, baseline_message),
+                                                      (make_test_pipeline(BaselineClassifier, MulticlassClassificationPipeline), ValueError, baseline_message),
+                                                      (make_test_pipeline(TimeSeriesBaselineEstimator, TimeSeriesRegressionPipeline), ValueError, baseline_message),
                                                       (make_test_pipeline(RandomForestClassifier, BinaryClassificationPipeline), ValueError, datatype_message),
                                                       (make_test_pipeline(LinearRegressor, RegressionPipeline), ValueError, data_message)])
 @patch("evalml.model_understanding.prediction_explanations._algorithms.shap.TreeExplainer")
 def test_value_errors_raised(mock_tree_explainer, pipeline, exception, match):
-
-    if "xgboost" in pipeline.name.lower():
+    if "xgboost" in pipeline.custom_name.lower():
         pytest.importorskip("xgboost", "Skipping test because xgboost is not installed.")
-    if "catboost" in pipeline.name.lower():
+    if "catboost" in pipeline.custom_name.lower():
         pytest.importorskip("catboost", "Skipping test because catboost is not installed.")
 
+    pipeline = pipeline({"pipeline": {"date_index": None, "gap": 1, "max_delay": 1}})
+
     with pytest.raises(exception, match=match):
-        _ = _compute_shap_values(pipeline({"pipeline": {"gap": 1, "max_delay": 1}}), pd.DataFrame(np.random.random((2, 16))))
+        _ = _compute_shap_values(pipeline, pd.DataFrame(np.random.random((2, 16))))
 
 
 def test_create_dictionary_exception():
@@ -93,7 +88,7 @@ def calculate_shap_for_test(training_data, y, pipeline, n_points_to_explain):
     return _compute_shap_values(pipeline, pd.DataFrame(points_to_explain), training_data)
 
 
-interpretable_estimators = [e for e in _all_estimators_used_in_search() if e.model_family not in {ModelFamily.XGBOOST, ModelFamily.BASELINE}]
+interpretable_estimators = [e for e in _all_estimators_used_in_search() if e.model_family != ModelFamily.BASELINE]
 all_problems = [ProblemTypes.REGRESSION, ProblemTypes.BINARY, ProblemTypes.MULTICLASS]
 all_n_points_to_explain = [1, 5]
 
@@ -106,9 +101,6 @@ def test_shap(estimator, problem_type, n_points_to_explain, X_y_binary, X_y_mult
     if problem_type not in estimator.supported_problem_types:
         pytest.skip("Skipping because estimator and pipeline are not compatible.")
 
-    if problem_type == ProblemTypes.MULTICLASS and estimator.model_family == ModelFamily.CATBOOST:
-        pytest.skip("Skipping Catboost for multiclass problems.")
-
     if problem_type == ProblemTypes.BINARY:
         training_data, y = X_y_binary
         is_binary = True
@@ -117,9 +109,11 @@ def test_shap(estimator, problem_type, n_points_to_explain, X_y_binary, X_y_mult
         is_binary = False
     else:
         training_data, y = X_y_regression
+    try:
+        pipeline = make_pipeline(training_data, y, estimator, problem_type, parameters={estimator.name: {'n_jobs': 1}})
+    except ValueError:
+        pipeline = make_pipeline(training_data, y, estimator, problem_type)
 
-    pipeline_class = make_pipeline(training_data, y, estimator, problem_type)
-    pipeline = helper_functions.safe_init_pipeline_with_njobs_1(pipeline_class)
     shap_values = calculate_shap_for_test(training_data, y, pipeline, n_points_to_explain)
 
     if problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
@@ -144,6 +138,24 @@ def test_shap(estimator, problem_type, n_points_to_explain, X_y_binary, X_y_mult
                    shap_values.values()), "A SHAP value must be computed for every data point to explain!"
 
 
+@patch('evalml.model_understanding.prediction_explanations._algorithms.logger')
+@patch('shap.TreeExplainer')
+def test_compute_shap_values_catches_shap_tree_warnings(mock_tree_explainer, mock_debug, X_y_binary, caplog):
+    X, y = X_y_binary
+    pipeline = BinaryClassificationPipeline(["Random Forest Classifier"])
+
+    def raise_warning_from_shap(estimator, feature_perturbation):
+        warnings.warn("Shap raised a warning!")
+        mock = MagicMock()
+        mock.shap_values.return_value = np.zeros(10)
+        return mock
+
+    mock_tree_explainer.side_effect = raise_warning_from_shap
+
+    _ = _compute_shap_values(pipeline, pd.DataFrame(X))
+    mock_debug.debug.assert_called_with("_compute_shap_values TreeExplainer: Shap raised a warning!")
+
+
 def test_normalize_values_exceptions():
 
     with pytest.raises(ValueError, match="^Unsupported data type for _normalize_shap_values"):
