@@ -154,11 +154,7 @@ def _get_subclasses(base_class):
 
 
 _not_used_in_automl = {'BaselineClassifier', 'BaselineRegressor', 'TimeSeriesBaselineEstimator',
-                       'StackedEnsembleClassifier', 'StackedEnsembleRegressor',
-                       'ModeBaselineBinaryPipeline', 'BaselineBinaryPipeline', 'MeanBaselineRegressionPipeline',
-                       'BaselineRegressionPipeline', 'ModeBaselineMulticlassPipeline', 'BaselineMulticlassPipeline',
-                       'TimeSeriesBaselineRegressionPipeline', 'TimeSeriesBaselineBinaryPipeline',
-                       'TimeSeriesBaselineMulticlassPipeline', 'KNeighborsClassifier',
+                       'StackedEnsembleClassifier', 'StackedEnsembleRegressor', 'KNeighborsClassifier',
                        'SVMClassifier', 'SVMRegressor', 'ARIMARegressor'}
 
 
@@ -319,7 +315,6 @@ def _get_rows_without_nans(*data):
             return ~pd_data.isna().any(axis=1).values
         else:
             return pd_data
-
     mask = reduce(lambda a, b: np.logical_and(_not_nan(a), _not_nan(b)), data)
     return mask
 
